import { createStore, compose, applyMiddleware } from "redux";
import createSagaMiddleware from "redux-saga";
import { persistStore, persistReducer } from "redux-persist";
import storage from "redux-persist/lib/storage";
import rootReducer from "./rootReducer";
import rootSaga from "./rootSaga";

const persistConfig = {
  key: "root",
  storage,
  timeout: 20 * 1000,
  blacklist: ["notification"]
};

const persistedReducer = persistReducer(persistConfig, rootReducer);

const composeEnhancers =
  // eslint-disable-next-line no-undef
  window.__REDUX_DEVTOOLS_EXTENSION_COMPOSE__ ||
  window.__REDUX_DEVTOOLS_EXTENSION__ ||
  compose;

const sagaMiddleware = createSagaMiddleware();

export const store = createStore(
  persistedReducer,
  composeEnhancers(applyMiddleware(sagaMiddleware))
);

export const persistor = persistStore(store, { timeout: 1000 });

sagaMiddleware.run(rootSaga);
